@@ -1,3 +1,5 @@
+# -*- indent-tabs-mode: t -*-
+
 #! /usr/bin/env python
 
 # Soya 3D
@@ -34,28 +36,28 @@ from distutils.core import setup
 sys.argv.extend(["--template", "MANIFEST_tuto.in", "--manifest", "MANIFEST_tuto"])
 
 setup(
-  name         = "SoyaTutorial",
-  version      = "0.10.1",
-  license      = "GPL",
-  description  = "A practical high-level object-oriented 3D engine for Python.",
-  long_description  = """A practical high-level object-oriented 3D engine for Python.
+	name         = "SoyaTutorial",
+	version      = "0.11.1",
+	license      = "GPL",
+	description  = "Tutorial for Soya, a practical high-level object-oriented 3D engine for Python.",
+	long_description  = """Tutorial for Soya, a practical high-level object-oriented 3D engine for Python.
 Soya is designed with game in mind. It includes heightmaps, particles systems, animation support,...""",
-  keywords     = "3D engine openGL python",
-  author       = "Jiba (LAMY Jean-Baptiste), Blam (LAMY Bertrand), LunacyMaze (GHISLAIN Mary)",
-  author_email = "jiba@tuxfamily.org",
-  url          = "http://gna.org/projects/soya/",
-  classifiers  = [
-  "Topic :: Multimedia :: Graphics :: 3D Rendering",
-  "Topic :: Software Development :: Libraries :: Python Modules",
-  "Programming Language :: Python",
-  "Intended Audience :: Developers",
-  "Development Status :: 5 - Production/Stable",
-  "License :: OSI Approved :: GNU General Public License (GPL)",
-  ],
-  
-  data_files   = [
-  ("tutorial", ["tutorial",]),
-  ],
-  
-  )
+	keywords     = "3D engine openGL python",
+	author       = "Jiba (LAMY Jean-Baptiste), Blam (LAMY Bertrand), LunacyMaze (GHISLAIN Mary)",
+	author_email = "jiba@tuxfamily.org",
+	url          = "http://home.gna.org/oomadness/en/soya/index.html",
+	classifiers  = [
+	"Topic :: Multimedia :: Graphics :: 3D Rendering",
+	"Topic :: Software Development :: Libraries :: Python Modules",
+	"Programming Language :: Python",
+	"Intended Audience :: Developers",
+	"Development Status :: 5 - Production/Stable",
+	"License :: OSI Approved :: GNU General Public License (GPL)",
+	],
+	
+	data_files   = [
+	("tutorial", ["tutorial",]),
+	],
+	
+	)
 
