@@ -1,3 +1,5 @@
+# -*- indent-tabs-mode: t -*-
+
 # Soya 3D tutorial
 # Copyright (C) 2004 Jean-Baptiste LAMY
 #
@@ -66,8 +68,8 @@ knife_model = soya.Shape.get("knife")
 #     cellshading=1
 #     cellshading_shader=shader_name
 #     cellshading_outline_width=5.0
-#     cellshading_outline_width=5.0
-#     cellshading_outline_width=5.0
+#     =5.0
+#     =5.0
 #     
 # The MATERIAL_MAP option has a different syntax. E.g. the following will replace the
 # material called "old_material_name" by the one called "new_material_name".
@@ -93,15 +95,15 @@ knife_model2 = soya.Shape.get("knife@with_sword_material")
 # Creates a rotating volume class.
 
 class RotatingVolume(soya.Volume):
-  def advance_time(self, proportion):
-    soya.Volume.advance_time(self, proportion)
-    self.rotate_lateral(proportion * 5.0)
+	def advance_time(self, proportion):
+		soya.Volume.advance_time(self, proportion)
+		self.rotate_y(proportion * 5.0)
 
 
 knife    = RotatingVolume(scene, knife_model )
 knife.x  = -1
 
-knife2 = RotatingVolume(scene, knife_model2)
+knife2   = RotatingVolume(scene, knife_model2)
 knife2.x = 1
 
 # Creates a light.
