@@ -1,3 +1,5 @@
+# -*- indent-tabs-mode: t -*-
+
 # Soya 3D tutorial
 # Copyright (C) 2004      Jean-Baptiste 'Jiba'  LAMY
 # Copyright (C) 2001-2002 Bertrand 'blam!' LAMY
@@ -30,6 +32,7 @@ import sys, os, os.path, soya, soya.sdlconst
 
 soya.init()
 soya.path.append(os.path.join(os.path.dirname(sys.argv[0]), "data"))
+soya.set_quality(2)
 
 # Creates the scene.
 
@@ -53,8 +56,15 @@ land.multiply_height(8.0)
 # (see lesson modeling-material-2 about texturing). First, we creates two textured
 # materials.
 
-material1 = soya.Material(soya.Image.get("block2.png"))
-material2 = soya.Material(soya.Image.get("metal1.png"))
+#material1 = soya.Material(soya.Image.get("block2.png"))
+#material2 = soya.Material(soya.Image.get("metal1.png"))
+material1 = soya.Material.get("block2")
+material2 = soya.Material.get("metal1")
+
+#material1 = soya.Material()
+#material1.diffuse = (0.0, 0.0, 0.0, 1.0)
+#material1 = soya.Material.get("block2")
+#material2 = soya.Material()
 
 # asigns MATERIAL1 to any point whose height is in the range 0.0-6.0, and material2 to
 # any point whose height is in the range 6.0-8.0 (remember, height ranges from 0.0 to 8.0).
@@ -63,7 +73,7 @@ land.set_material_layer(material1, 0.0, 6.0)
 land.set_material_layer(material2, 6.0, 8.0)
 
 # Assigns material1 to any point whose height is in the range 0.0-8.0 and if the angle
-# between the surface normal and the verticalvector is in the range 0.0-20.0.
+# between the surface normal and the vertical vector is in the range 0.0-20.0.
 
 land.set_material_layer_angle(material1, 0.0, 8.0, 0.0, 20.0)
 
@@ -80,15 +90,16 @@ land.set_material_layer_angle(material1, 0.0, 8.0, 0.0, 20.0)
 #    The higher split_factor is, the better precision you have (it means more triangles
 #    to draw the Land even far from Camera).
 #    
-#    map_size represents the size of a map. A map is a square part of the Land that
+#    patch_size represents the size of patches. A patch is a square part of the Land that
 #    computes its visibility and precision.
 
 # the values below are the default ones.
  
 land.texture_factor = 1.0
 land.scale_factor   = 1.0
-land.map_size       = 8
+land.patch_size     = 8
 land.split_factor   = 2.0
+land.texture_factor = 0.25
 
 # Moves the landscape.
 
@@ -102,35 +113,35 @@ light.set_xyz(0.0, 15.0, 0.0)
 # Adds a keyboard-controlled camera and a rendering loop
 
 class MovableCamera(soya.Camera):
-  def __init__(self, parent):
-    soya.Camera.__init__(self, parent)
-    
-    self.speed = soya.Vector(self)
-    self.rotation_lateral_speed  = 0.0
-    self.rotation_vertical_speed = 0.0
-    
-  def begin_round(self):
-    soya.Camera.begin_round(self)
-    
-    for event in soya.process_event():
-      if event[0] == soya.sdlconst.KEYDOWN:
-        if   event[1] == soya.sdlconst.K_UP:     self.speed.z = -1.0
-        elif event[1] == soya.sdlconst.K_DOWN:   self.speed.z =  1.0
-        elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_lateral_speed =  10.0
-        elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_lateral_speed = -10.0
-        elif event[1] == soya.sdlconst.K_q:      soya.IDLER.stop()
-        elif event[1] == soya.sdlconst.K_ESCAPE: soya.IDLER.stop()
-      if event[0] == soya.sdlconst.KEYUP:
-        if   event[1] == soya.sdlconst.K_UP:     self.speed.z = 0.0
-        elif event[1] == soya.sdlconst.K_DOWN:   self.speed.z = 0.0
-        elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_lateral_speed = 0.0
-        elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_lateral_speed = 0.0
-      
-  def advance_time(self, proportion):
-    self.add_mul_vector(proportion, self.speed)
-    self.turn_lateral (self.rotation_lateral_speed  * proportion)
-    self.turn_vertical(self.rotation_vertical_speed * proportion)
-    
+	def __init__(self, parent):
+		soya.Camera.__init__(self, parent)
+		
+		self.speed = soya.Vector(self)
+		self.rotation_y_speed = 0.0
+		self.rotation_x_speed = 0.0
+		
+	def begin_round(self):
+		soya.Camera.begin_round(self)
+		
+		for event in soya.process_event():
+			if event[0] == soya.sdlconst.KEYDOWN:
+				if   event[1] == soya.sdlconst.K_UP:     self.speed.z = -1.0
+				elif event[1] == soya.sdlconst.K_DOWN:   self.speed.z =  1.0
+				elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_y_speed =  10.0
+				elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_y_speed = -10.0
+				elif event[1] == soya.sdlconst.K_q:      soya.IDLER.stop()
+				elif event[1] == soya.sdlconst.K_ESCAPE: soya.IDLER.stop()
+			if event[0] == soya.sdlconst.KEYUP:
+				if   event[1] == soya.sdlconst.K_UP:     self.speed.z = 0.0
+				elif event[1] == soya.sdlconst.K_DOWN:   self.speed.z = 0.0
+				elif event[1] == soya.sdlconst.K_LEFT:   self.rotation_y_speed = 0.0
+				elif event[1] == soya.sdlconst.K_RIGHT:  self.rotation_y_speed = 0.0
+			
+	def advance_time(self, proportion):
+		self.add_mul_vector(proportion, self.speed)
+		self.turn_y(self.rotation_y_speed * proportion)
+		self.turn_x(self.rotation_x_speed * proportion)
+		
 
 camera = MovableCamera(scene)
 camera.set_xyz(16.0, 6.0, 0.0)
@@ -138,25 +149,18 @@ camera.look_at(soya.Point(scene, 16.0, 6.0, 10.0))
 soya.set_root_widget(camera)
 
 
+#camera.set_xyz(16.0, 8.0, 0.0)
+#camera.look_at(soya.Point(scene, 16.0, 6.0, 10.0))
 
 
 scene.x = 100.0
 
-print soya.Point(scene, 3.0, 1000.0, 3.0) % scene
 
-v = soya.Volume(scene, soya.Shape.get("sword"))
-v.set_xyz(3.0, 7.0, 3.0)
+scene.atmosphere = soya.Atmosphere()
+scene.atmosphere.ambient = (1.0, 1.0, 1.0, 1.0)
 
-print
-print scene.raypick(
-  soya.Point (scene, 3.0, 1000.0, 3.0),
-  soya.Vector(scene, 0.0,   -1.0, 0.0001),
-  )
-print
-print scene.raypick_b(
-  soya.Point (scene, 3.1, 1000.0, 3.1),
-  soya.Vector(scene, 0.0,   -1.0, 0.0001),
-  )
-print
-
-soya.Idler(scene).idle()
+#soya.Idler(scene).idle()
+i = soya.Idler(scene)
+#i.min_frame_duration = 0.0
+i.idle()
+print i.fps
